// +-------------------------------------------+
// |  ___   _     _____   __  __  ____   ____  |
// | | __| | |   | /_\ |  \ \/ / | ___| | /\ | |
// | |__ | | |_  |  _  |   \  /  | __|  | \/ / |
// | |___| |___| |_| |_|   |__|  |____| |_| \\ |
// |  Greek2me              Blockland ID 11902 |
// +-------------------------------------------+

//Create the game mode template.
new ScriptGroup(Slayer_GameModeTemplateSG)
{
	className = "Slayer_TeamInfection";
	uiName = "Team Infection";
	useTeams = true;
	
	//Team settings
	teams_minTeams = 2; //user must create at least two teams
	
	//Default preferences:
	default_teams_notifyMemberChanges = false;
	default_teams_teamOnlyDeadcam = true;
	
	//Locked preferences:
	locked_teams_balanceTeams = false;
	locked_teams_lock = true;
	locked_teams_shuffleTeams = false;
};

//Slayer v3 compatibility.
$Slayer::GameModes::NewClass["INF"] = "Slayer_TeamInfection";

function Slayer_TeamInfection::onClientDisplayRules(%this, %client)
{
	messageClient(%client,'',"\c5 + When you kill enemy players, they will join your team.");
}

function Slayer_TeamInfection::onPlayerDeath(%this, %victim, %obj, %killer, %type, %area)
{
	%mini = %this.minigame;
	%viTeam = %victim.getTeam();
	if(isObject(%killer))
		%kiTeam = %killer.getTeam();

	if(isObject(%kiTeam) && %kiTeam.sort && %kiTeam.sortWeight > 0 && (%kiTeam.numMembers_["GameConnection"] < %kiTeam.maxPlayers || %kiTeam.maxPlayers == -1))
	{
		if(!isObject(%viTeam) || (!%kiTeam.isAlliedTeam(%viTeam) && %viTeam.INF_swapOnDeath))
		{
			%viTeam.INF_playersLost ++;
			%kiTeam.INF_playersGained ++;

			//disable team join messages
			%oldNotify = %mini.teams_notifyMemberChanges;
			%mini.teams_notifyMemberChanges = false;
			//disable bot team-filling
			%viTeamFill = %viTeam.botFillLimit;
			%viTeam.botFillLimit = -1;
			%kiTeamFill = %kiTeam.botFillLimit;
			%kiTeam.botFillLimit = -1;

			%kiTeam.addMember(%victim,"",true);

			%mini.teams_notifyMemberChanges = %oldNotify;
			%viTeam.botFillLimit = %viTeamFill;
			%kiTeam.botFillLimit = %kiTeamFill;

			%winner = %mini.victoryCheck_Lives();
			if(%winner >= 0)
				%mini.endRound(%winner);
		}
	}
}

function Slayer_TeamInfection::preMinigameReset(%this, %client)
{
	%mini = %this.minigame;
	for(%i = 0; %i < %mini.teams.getCount(); %i ++)
	{
		%team = %mini.teams.getObject(%i);
		%team.INF_playersGained = 0;
		%team.INF_playersLost = 0;
	}

	//disable team join messages
	%oldNotify = %mini.teams_notifyMemberChanges;
	%mini.teams_notifyMemberChanges = false;

	%mini.teams.balanceTeams(true);

	%mini.teams_notifyMemberChanges = %oldNotify;
}

function Slayer_TeamInfection::scoreListInit(%this, %header, %var1, %var2, %var3, %var4, %var5, %var6, %var7, %var8, %var9)
{
	//150,234,318,402,486//440
	%header = '<color:ffffff><tab:150,234,318,402,486><font:arial:16>%1<h2>%2\t%3\t%4\t%5\t%6\t%7</h2><br>';
	%var6 = "Players Gained/Lost";
	return true TAB %header TAB %var1 TAB %var2 TAB %var3 TAB %var4 TAB %var5 TAB %var6 TAB %var7 TAB %var8 TAB %var9;
}

function Slayer_TeamInfection::scoreListAdd(%this, %obj, %line, %var1, %var2, %var3, %var4, %var5, %var6, %var7, %var8, %var9)
{
	%line = '<color:%1><b>%2</b></color>\t%3\t%4\t%5\t%6\t%7<br>';

	if(%obj.class $= "Slayer_TeamSO")
	{
		%var6 = (%obj.INF_playersGained $= "" ? 0 : %obj.INF_playersGained);
		%var7 = (%obj.INF_playersLost $= "" ? 0 : %obj.INF_playersLost);
	}
	else
	{
		%var6 = "";
		%var7 = "";
	}

	return true TAB %line TAB %var1 TAB %var2 TAB %var3 TAB %var4 TAB %var5 TAB %var6 TAB %var7 TAB %var8 TAB %var9;
}